@@ -13,6 +13,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+from debtcollector import removals
 import flask
 import webob.dec
 from oslo_config import cfg
@@ -47,7 +48,6 @@ cfg.CONF.register_opts([
                     "the original request protocol scheme was, even if it was "
                     "removed by an SSL terminating proxy."),
     cfg.StrOpt('override-proto',
-               default=None,
                help="A scheme that will be used to override "
                     "the request protocol scheme, even if it was "
                     "set by an SSL terminating proxy.")
@@ -62,7 +62,7 @@ def auth_pipeline_factory(loader, global_conf, **local_conf):
     """
     pipeline = local_conf[cfg.CONF['service:api'].auth_strategy]
     pipeline = pipeline.split()
-    LOG.info(_LI('Getting auth pipeline: %s') % pipeline[:-1])
+    LOG.info(_LI('Getting auth pipeline: %s'), pipeline[:-1])
     filters = [loader.get_filter(n) for n in pipeline[:-1]]
     app = loader.get_app(pipeline[-1])
     filters.reverse()
@@ -215,7 +215,7 @@ class MaintenanceMiddleware(base.Middleware):
         # If the caller has the bypass role, let them through
         if ('context' in request.environ
                 and self.role in request.environ['context'].roles):
-            LOG.warn(_LW('Request authorized to bypass maintenance mode'))
+            LOG.warning(_LW('Request authorized to bypass maintenance mode'))
             return None
 
         # Otherwise, reject the request with a 503 Service Unavailable
@@ -272,6 +272,9 @@ class FaultWrapperMiddleware(base.Middleware):
             # Handle all other exception types
             return self._handle_exception(request, e)
 
+    def _format_error(self, data):
+        pass
+
     def _handle_exception(self, request, e, status=500, response=None):
 
         response = response or {}
@@ -292,6 +295,8 @@ class FaultWrapperMiddleware(base.Middleware):
         if 'type' not in response:
             response['type'] = 'unknown'
 
+        self._format_error(response)
+
         # Return the new response
         if 'context' in request.environ:
             response['request_id'] = request.environ['context'].request_id
@@ -307,6 +312,17 @@ class FaultWrapperMiddleware(base.Middleware):
                               response=json.dumps(response))
 
 
+class FaultWrapperMiddlewareV1(FaultWrapperMiddleware):
+    def _format_error(self, data):
+        replace_map = [
+            ("zone", "domain",)
+        ]
+
+        for i in replace_map:
+            data["type"] = data["type"].replace(i[0], i[1])
+        print(data)
+
+
 class ValidationErrorMiddleware(base.Middleware):
 
     def __init__(self, application):
@@ -378,6 +394,8 @@ class SSLMiddleware(base.Middleware):
 
     Code nabbed from Heat.
     """
+    # Replaced by oslo.middleware's http_proxy_to_wsgi middleware
+    @removals.remove
     def __init__(self, application):
         super(SSLMiddleware, self).__init__(application)
         LOG.info(_LI('Starting designate ssl middleware'))
