@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hp.com>
+# Author: Kiall Mac Innes <kiall@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -17,8 +17,6 @@ import pecan.deploy
 from oslo_config import cfg
 from oslo_log import log as logging
 
-from designate.api.v2 import patches  # flake8: noqa
-
 
 LOG = logging.getLogger(__name__)
 
@@ -34,6 +32,7 @@ OPTS = [
 
 cfg.CONF.register_opts(OPTS, group='service:api')
 
+
 def factory(global_config, **local_conf):
     if not cfg.CONF['service:api'].enable_api_v2:
         def disabled_app(environ, start_response):
@@ -50,7 +49,7 @@ def factory(global_config, **local_conf):
             'errors': {
                 404: '/errors/not_found',
                 405: '/errors/method_not_allowed',
-                '__force_dict__' : True
+                '__force_dict__': True
             }
         }
     }
