@@ -1,6 +1,6 @@
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
-# Author: Graham Hayes <graham.hayes@hp.com>
+# Author: Graham Hayes <graham.hayes@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -75,6 +75,8 @@ class TransferRequestsController(rest.RestController):
         except exceptions.EmptyRequestBody:
             body = dict()
 
+        zone = self.central_api.get_zone(context, zone_id)
+        body['zone_name'] = zone.name
         body['zone_id'] = zone_id
 
         zone_transfer_request = DesignateAdapter.parse(
