@@ -1,6 +1,6 @@
 # Copyright 2015 Hewlett-Packard Development Company, L.P.
 #
-# Author: Endre Karlson <endre.karlson@hp.com>
+# Author: Endre Karlson <endre.karlson@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -29,7 +29,7 @@ class XfrController(rest.RestController):
         response = pecan.response
         context = request.environ['context']
 
-        self.central_api.xfr_domain(context, zone_id)
+        self.central_api.xfr_zone(context, zone_id)
         response.status_int = 202
 
         # NOTE: This is a hack and a half.. But Pecan needs it.
