@@ -67,10 +67,10 @@ class AgentPoolBackend(base.Backend):
     def mdns_api(self):
         return mdns_api.MdnsAPI.get_instance()
 
-    def create_domain(self, context, domain):
-        LOG.debug('Create Domain')
+    def create_zone(self, context, zone):
+        LOG.debug('Create Zone')
         response, retry = self._make_and_send_dns_message(
-            domain.name,
+            zone.name,
             self.timeout,
             CC,
             CREATE,
@@ -81,12 +81,12 @@ class AgentPoolBackend(base.Backend):
         if response is None:
             raise exceptions.Backend()
 
-    def update_domain(self, context, domain):
-        LOG.debug('Update Domain')
+    def update_zone(self, context, zone):
+        LOG.debug('Update Zone')
 
         self.mdns_api.notify_zone_changed(
             context,
-            domain,
+            zone,
             self.host,
             self.port,
             self.timeout,
@@ -95,10 +95,10 @@ class AgentPoolBackend(base.Backend):
             self.delay
         )
 
-    def delete_domain(self, context, domain):
-        LOG.debug('Delete Domain')
+    def delete_zone(self, context, zone):
+        LOG.debug('Delete Zone')
         response, retry = self._make_and_send_dns_message(
-            domain.name,
+            zone.name,
             self.timeout,
             CC,
             DELETE,
@@ -109,38 +109,38 @@ class AgentPoolBackend(base.Backend):
         if response is None:
             raise exceptions.Backend()
 
-    def _make_and_send_dns_message(self, domain_name, timeout, opcode,
-                                  rdatatype, rdclass, dest_ip,
-                                  dest_port):
-        dns_message = self._make_dns_message(domain_name, opcode, rdatatype,
+    def _make_and_send_dns_message(self, zone_name, timeout, opcode,
+                                   rdatatype, rdclass, dest_ip,
+                                   dest_port):
+        dns_message = self._make_dns_message(zone_name, opcode, rdatatype,
                                              rdclass)
 
         retry = 0
         response = None
 
         LOG.info(_LI("Sending '%(msg)s' for '%(zone)s' to '%(server)s:"
-                     "%(port)d'.") %
+                     "%(port)d'."),
                  {'msg': str(opcode),
-                  'zone': domain_name, 'server': dest_ip,
+                  'zone': zone_name, 'server': dest_ip,
                   'port': dest_port})
         response = self._send_dns_message(
             dns_message, dest_ip, dest_port, timeout)
 
         if isinstance(response, dns.exception.Timeout):
-            LOG.warn(_LW("Got Timeout while trying to send '%(msg)s' for "
+            LOG.warning(_LW("Got Timeout while trying to send '%(msg)s' for "
                          "'%(zone)s' to '%(server)s:%(port)d'. Timeout="
                          "'%(timeout)d' seconds. Retry='%(retry)d'") %
                      {'msg': str(opcode),
-                      'zone': domain_name, 'server': dest_ip,
+                      'zone': zone_name, 'server': dest_ip,
                       'port': dest_port, 'timeout': timeout,
                       'retry': retry})
             response = None
         elif isinstance(response, dns_query.BadResponse):
-            LOG.warn(_LW("Got BadResponse while trying to send '%(msg)s' "
+            LOG.warning(_LW("Got BadResponse while trying to send '%(msg)s' "
                          "for '%(zone)s' to '%(server)s:%(port)d'. Timeout"
                          "='%(timeout)d' seconds. Retry='%(retry)d'") %
                      {'msg': str(opcode),
-                      'zone': domain_name, 'server': dest_ip,
+                      'zone': zone_name, 'server': dest_ip,
                       'port': dest_port, 'timeout': timeout,
                       'retry': retry})
             response = None
@@ -149,11 +149,11 @@ class AgentPoolBackend(base.Backend):
         # authoritative answer
         elif not (response.flags & dns.flags.AA) or dns.rcode.from_flags(
                 response.flags, response.ednsflags) != dns.rcode.NOERROR:
-            LOG.warn(_LW("Failed to get expected response while trying to "
+            LOG.warning(_LW("Failed to get expected response while trying to "
                          "send '%(msg)s' for '%(zone)s' to '%(server)s:"
                          "%(port)d'. Response message: %(resp)s") %
                      {'msg': str(opcode),
-                      'zone': domain_name, 'server': dest_ip,
+                      'zone': zone_name, 'server': dest_ip,
                       'port': dest_port, 'resp': str(response)})
             response = None
             return (response, retry)
