@@ -1,6 +1,6 @@
 # Copyright 2015 Hewlett-Packard Development Company, L.P.
 #
-# Author: Endre Karlson <endre.karlson@hp.com>
+# Author: Endre Karlson <endre.karlson@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -15,9 +15,9 @@
 # under the License.
 from designateclient.v2 import client
 from designateclient import exceptions
-from keystoneclient.auth.identity import v2 as v2_auth
-from keystoneclient.auth.identity import v3 as v3_auth
-from keystoneclient import session as ks_session
+from keystoneauth1.identity import v2 as v2_auth
+from keystoneauth1.identity import v3 as v3_auth
+from keystoneauth1 import session as ks_session
 from oslo_config import cfg
 from oslo_log import log as logging
 
@@ -87,20 +87,20 @@ class DesignateBackend(base.Backend):
             session=session, service_type=self.service_type)
         return self._client
 
-    def create_domain(self, context, domain):
-        msg = _LI('Creating domain %(d_id)s / %(d_name)s')
-        LOG.info(msg, {'d_id': domain['id'], 'd_name': domain['name']})
+    def create_zone(self, context, zone):
+        msg = _LI('Creating zone %(d_id)s / %(d_name)s')
+        LOG.info(msg, {'d_id': zone['id'], 'd_name': zone['name']})
 
         masters = ["%s:%s" % (i.host, i.port) for i in self.masters]
         self.client.zones.create(
-            domain.name, 'SECONDARY', masters=masters)
+            zone.name, 'SECONDARY', masters=masters)
 
-    def delete_domain(self, context, domain):
-        msg = _LI('Deleting domain %(d_id)s / %(d_name)s')
-        LOG.info(msg, {'d_id': domain['id'], 'd_name': domain['name']})
+    def delete_zone(self, context, zone):
+        msg = _LI('Deleting zone %(d_id)s / %(d_name)s')
+        LOG.info(msg, {'d_id': zone['id'], 'd_name': zone['name']})
 
         try:
-            self.client.zones.delete(domain.name)
+            self.client.zones.delete(zone.name)
         except exceptions.NotFound:
             msg = _LW("Zone %s not found on remote Designate, Ignoring")
-            LOG.warn(msg, domain.id)
+            LOG.warning(msg, zone.id)
