@@ -1,6 +1,6 @@
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
-# Author: Graham Hayes <graham.hayes@hp.com>
+# Author: Graham Hayes <graham.hayes@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -25,7 +25,7 @@ class ZoneTransferRequest(base.DictObjectMixin, base.PersistentObjectMixin,
                 "maxLength": 160
             },
         },
-        'domain_id': {
+        'zone_id': {
             'schema': {
                 "type": "string",
                 "description": "Zone identifier",
@@ -57,7 +57,7 @@ class ZoneTransferRequest(base.DictObjectMixin, base.PersistentObjectMixin,
                 "enum": ["ACTIVE", "PENDING", "DELETED", "ERROR", "COMPLETE"],
             }
         },
-        'domain_name': {
+        'zone_name': {
             'schema': {
                 "type": ["string", "null"],
                 "maxLength": 255,
@@ -67,7 +67,7 @@ class ZoneTransferRequest(base.DictObjectMixin, base.PersistentObjectMixin,
     }
 
     STRING_KEYS = [
-        'id', 'domain_id', 'domain_name', 'target_tenant_id'
+        'id', 'zone_id', 'zone_name', 'target_tenant_id'
     ]
 
 
