@@ -1,7 +1,7 @@
 # Copyright 2012 Managed I.T.
 # Copyright 2015 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hp.com>
+# Author: Kiall Mac Innes <kiall@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -16,8 +16,11 @@
 # under the License.
 from __future__ import absolute_import
 
+import os
+import random
 import shutil
 import tempfile
+from contextlib import contextmanager
 
 import fixtures
 from oslo_log import log as logging
@@ -31,6 +34,8 @@ from designate import rpc
 from designate.network_api import fake as fake_network_api
 from designate.sqlalchemy import utils as sqlalchemy_utils
 
+"""Test fixtures
+"""
 
 LOG = logging.getLogger(__name__)
 
@@ -100,8 +105,19 @@ class DatabaseFixture(fixtures.Fixture):
         return DatabaseFixture.fixtures[repo_path]
 
     def _mktemp(self):
+        """Create temporary database file
+        """
+        tmpfs_path = "/dev/shm"
+        if os.path.isdir(tmpfs_path):
+            tmp_dir = tmpfs_path
+            LOG.debug("Using tmpfs on %s as database tmp dir" % tmp_dir)
+        else:
+            tmp_dir = "/tmp"
+            LOG.warning("Using %s as database tmp dir. Tests might be slow" %
+                        tmp_dir)
+
         _, path = tempfile.mkstemp(prefix='designate-', suffix='.sqlite',
-                                   dir='/tmp')
+                                   dir=tmp_dir)
         return path
 
     def __init__(self, repo_path, init_version=None):
@@ -124,6 +140,12 @@ class DatabaseFixture(fixtures.Fixture):
         super(DatabaseFixture, self).setUp()
         shutil.copyfile(self.golden_db, self.working_copy)
 
+    def tearDown(self):
+        # This is currently unused
+        super(DatabaseFixture, self).tearDown()
+        LOG.debug("Deleting %s" % self.working_copy)
+        os.unlink(self.working_copy)
+
 
 class NetworkAPIFixture(fixtures.Fixture):
     def setUp(self):
@@ -142,3 +164,13 @@ class ZoneManagerTaskFixture(fixtures.Fixture):
         super(ZoneManagerTaskFixture, self).setUp()
         self.task = self._task_cls()
         self.task.on_partition_change(range(0, 4095), None, None)
+
+
+@contextmanager
+def random_seed(seed):
+    """Context manager to set random.seed() temporarily
+    """
+    state = random.getstate()
+    random.seed(seed)
+    yield
+    random.setstate(state)
