@@ -1,6 +1,6 @@
 # Copyright 2015 Hewlett-Packard Development Company, L.P.
 #
-# Author: Endre Karlson <endre.karlson@hp.com>
+# Author: Endre Karlson <endre.karlson@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -13,14 +13,18 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import uuid
 
+"""
+Unit test Backend
+"""
+import uuid
 
 from designateclient import exceptions
 from mock import patch
 from mock import NonCallableMagicMock
 from mock import Mock
 from oslo_log import log as logging
+import fixtures
 import oslotest.base
 import testtools
 
@@ -32,7 +36,7 @@ LOG = logging.getLogger(__name__)
 
 def create_zone():
     id_ = str(uuid.uuid4())
-    return objects.Domain(
+    return objects.Zone(
         id=id_,
         name='%s-example.com.' % id_,
         email='root@example.com',
@@ -57,8 +61,8 @@ class DesignateBackendTest(oslotest.base.BaseTestCase):
             username='user',
             password='secret',
             project_name='project',
-            project_domain_name='project_domain',
-            user_domain_name='user_domain'
+            project_zone_name='project_zone',
+            user_zone_name='user_zone'
         )
         self.target = RoObject({
             'id': '4588652b-50e7-46b9-b688-a9bad40a873e',
@@ -70,11 +74,10 @@ class DesignateBackendTest(oslotest.base.BaseTestCase):
         # Backends blow up when trying to self.admin_context = ... due to
         # policy not being initialized
         self.admin_context = Mock()
-        get_context_patcher = patch(
-            'designate.context.DesignateContext.get_admin_context')
-        self.addCleanup(get_context_patcher.stop)
-        get_context = get_context_patcher.start()
-        get_context.return_value = self.admin_context
+        self.useFixture(fixtures.MockPatch(
+            'designate.context.DesignateContext.get_admin_context',
+            return_value=self.admin_context
+        ))
 
         self.backend = impl_designate.DesignateBackend(self.target)
 
@@ -84,31 +87,31 @@ class DesignateBackendTest(oslotest.base.BaseTestCase):
             'create', 'delete'])
         self.client.configure_mock(zones=zones)
 
-    def test_create_domain(self):
+    def test_create_zone(self):
         zone = create_zone()
         masters = ["%(host)s:%(port)s" % self.target.masters[0]]
         with patch.object(
                 self.backend, '_get_client', return_value=self.client):
-            self.backend.create_domain(self.admin_context, zone)
+            self.backend.create_zone(self.admin_context, zone)
         self.client.zones.create.assert_called_once_with(
             zone.name, 'SECONDARY', masters=masters)
 
-    def test_delete_domain(self):
+    def test_delete_zone(self):
         zone = create_zone()
         with patch.object(
                 self.backend, '_get_client', return_value=self.client):
-            self.backend.delete_domain(self.admin_context, zone)
+            self.backend.delete_zone(self.admin_context, zone)
         self.client.zones.delete.assert_called_once_with(zone.name)
 
-    def test_delete_domain_notfound(self):
+    def test_delete_zone_notfound(self):
         zone = create_zone()
         self.client.delete.side_effect = exceptions.NotFound
         with patch.object(
                 self.backend, '_get_client', return_value=self.client):
-            self.backend.delete_domain(self.admin_context, zone)
+            self.backend.delete_zone(self.admin_context, zone)
         self.client.zones.delete.assert_called_once_with(zone.name)
 
-    def test_delete_domain_exc(self):
+    def test_delete_zone_exc(self):
         class Exc(Exception):
             pass
 
@@ -117,5 +120,5 @@ class DesignateBackendTest(oslotest.base.BaseTestCase):
         with testtools.ExpectedException(Exc):
             with patch.object(
                     self.backend, '_get_client', return_value=self.client):
-                self.backend.delete_domain(self.admin_context, zone)
+                self.backend.delete_zone(self.admin_context, zone)
         self.client.zones.delete.assert_called_once_with(zone.name)
