@@ -29,11 +29,10 @@ from oslo_concurrency import processutils
 from oslo_log import log as logging
 from oslo_utils import timeutils
 
+from designate.common import config
 from designate import exceptions
 from designate.i18n import _
 from designate.i18n import _LI
-from designate.openstack.common.report import guru_meditation_report as gmr
-from designate import version as designate_version
 
 
 LOG = logging.getLogger(__name__)
@@ -52,9 +51,9 @@ cfg.CONF.register_group(cfg.OptGroup(
 ))
 
 proxy_opts = [
-    cfg.StrOpt('http_proxy', default=None,
+    cfg.StrOpt('http_proxy',
                help='Proxy HTTP requests via this proxy.'),
-    cfg.StrOpt('https_proxy', default=None,
+    cfg.StrOpt('https_proxy',
                help='Proxy HTTPS requests via this proxy'),
     cfg.ListOpt('no_proxy', default=[],
                 help='These addresses should not be proxied')
@@ -96,6 +95,7 @@ def read_config(prog, argv):
     config_files = find_config('%s.conf' % prog)
     cfg.CONF(argv[1:], project='designate', prog=prog,
              default_config_files=config_files)
+    config.set_defaults()
 
     register_plugin_opts()
 
@@ -169,6 +169,8 @@ def render_template_to_file(template_name, output_path, makedirs=True,
 
 
 def execute(*cmd, **kw):
+    """Execute a command in a subprocess, blocking.
+    """
     root_helper = kw.pop('root_helper', cfg.CONF.root_helper)
     run_as_root = kw.pop('run_as_root', True)
     return processutils.execute(*cmd, run_as_root=run_as_root,
@@ -394,10 +396,6 @@ def cache_result(function):
     return wrapper
 
 
-def setup_gmr(log_dir=None):
-    gmr.TextGuruMeditation.setup_autorun(designate_version, log_dir=log_dir)
-
-
 def split_host_port(string, default_port=53):
     try:
         (host, port) = string.split(':', 1)
@@ -459,7 +457,7 @@ def get_paging_params(params, sort_keys):
 
 def bind_tcp(host, port, tcp_backlog, tcp_keepidle=None):
     # Bind to the TCP port
-    LOG.info(_LI('Opening TCP Listening Socket on %(host)s:%(port)d') %
+    LOG.info(_LI('Opening TCP Listening Socket on %(host)s:%(port)d'),
              {'host': host, 'port': port})
     sock_tcp = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
     sock_tcp.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
@@ -486,7 +484,7 @@ def bind_tcp(host, port, tcp_backlog, tcp_keepidle=None):
 
 def bind_udp(host, port):
     # Bind to the UDP port
-    LOG.info(_LI('Opening UDP Listening Socket on %(host)s:%(port)d') %
+    LOG.info(_LI('Opening UDP Listening Socket on %(host)s:%(port)d'),
              {'host': host, 'port': port})
     sock_udp = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
     sock_udp.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
