@@ -1,6 +1,6 @@
 # Copyright 2015 Hewlett-Packard Development Company, L.P.
 #
-# Author: Endre Karlson <endre.karlson@hp.com>
+# Author: Endre Karlson <endre.karlson@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -22,11 +22,11 @@ CONF.register_group(cfg.OptGroup(
 ))
 
 OPTS = [
-    cfg.IntOpt('workers', default=None,
+    cfg.IntOpt('workers',
                help='Number of Zone Manager worker processes to spawn'),
     cfg.IntOpt('threads', default=1000,
                help='Number of Zone Manager greenthreads to spawn'),
-    cfg.ListOpt('enabled_tasks', default=None,
+    cfg.ListOpt('enabled_tasks',
                 help='Enabled tasks to run'),
     cfg.StrOpt('storage-driver', default='sqlalchemy',
                help='The storage driver to use'),
