@@ -1,6 +1,6 @@
 # Copyright 2015 Hewlett-Packard Development Company, L.P.
 #
-# Author: Endre Karlson <endre.karlson@hp.com>
+# Author: Endre Karlson <endre.karlson@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -20,6 +20,7 @@ from designate import plugin
 from designate import rpc
 from designate.central import rpcapi
 from designate.i18n import _LI
+from designate.pool_manager.rpcapi import PoolManagerAPI
 
 from oslo_config import cfg
 from oslo_log import log as logging
@@ -87,20 +88,20 @@ class PeriodicTask(plugin.ExtensionPlugin):
     def _iter_zones(self, ctxt, criterion=None):
         criterion = criterion or {}
         criterion.update(self._filter_between('shard'))
-        return self._iter(self.central_api.find_domains, ctxt, criterion)
+        return self._iter(self.central_api.find_zones, ctxt, criterion)
 
 
-class DeletedDomainPurgeTask(PeriodicTask):
-    """Purge deleted domains that are exceeding the grace period time interval.
-    Deleted domains have values in the deleted_at column.
+class DeletedZonePurgeTask(PeriodicTask):
+    """Purge deleted zones that are exceeding the grace period time interval.
+    Deleted zones have values in the deleted_at column.
     Purging means removing them from the database entirely.
     """
 
-    __plugin_name__ = 'domain_purge'
+    __plugin_name__ = 'zone_purge'
     __interval__ = 3600
 
     def __init__(self):
-        super(DeletedDomainPurgeTask, self).__init__()
+        super(DeletedZonePurgeTask, self).__init__()
 
     @classmethod
     def get_cfg_opts(cls):
@@ -109,13 +110,13 @@ class DeletedDomainPurgeTask(PeriodicTask):
             cfg.IntOpt(
                 'time_threshold',
                 default=604800,
-                help="How old deleted domains should be (deleted_at) to be "
+                help="How old deleted zones should be (deleted_at) to be "
                 "purged, in seconds"
             ),
             cfg.IntOpt(
                 'batch_size',
                 default=100,
-                help='How many domains to be purged on each run'
+                help='How many zones to be purged on each run'
             ),
         ]
         return [(group, options)]
@@ -125,12 +126,12 @@ class DeletedDomainPurgeTask(PeriodicTask):
         expiration time and sharding range.
         """
         pstart, pend = self._my_range()
-        msg = _LI("Performing deleted domain purging for %(start)s to %(end)s")
-        LOG.info(msg % {"start": pstart, "end": pend})
+        msg = _LI("Performing deleted zone purging for %(start)s to %(end)s")
+        LOG.info(msg, {"start": pstart, "end": pend})
 
         delta = datetime.timedelta(seconds=self.options.time_threshold)
         time_threshold = timeutils.utcnow() - delta
-        LOG.debug("Filtering deleted domains before %s", time_threshold)
+        LOG.debug("Filtering deleted zones before %s", time_threshold)
 
         criterion = self._filter_between('shard')
         criterion['deleted'] = '!0'
@@ -139,7 +140,7 @@ class DeletedDomainPurgeTask(PeriodicTask):
         ctxt = context.DesignateContext.get_admin_context()
         ctxt.all_tenants = True
 
-        self.central_api.purge_domains(
+        self.central_api.purge_zones(
             ctxt,
             criterion,
             limit=self.options.batch_size,
@@ -170,7 +171,7 @@ class PeriodicExistsTask(PeriodicTask):
         pstart, pend = self._my_range()
 
         msg = _LI("Emitting zone exist events for shards %(start)s to %(end)s")
-        LOG.info(msg % {"start": pstart, "end": pend})
+        LOG.info(msg, {"start": pstart, "end": pend})
 
         ctxt = context.DesignateContext.get_admin_context()
         ctxt.all_tenants = True
@@ -191,6 +192,7 @@ class PeriodicExistsTask(PeriodicTask):
             zone_data.update(extra_data)
 
             self.notifier.info(ctxt, 'dns.domain.exists', zone_data)
+            self.notifier.info(ctxt, 'dns.zone.exists', zone_data)
 
         LOG.info(_LI("Finished emitting %(counter)d events for shards "
                      "%(start)s to %(end)s"),
@@ -210,7 +212,7 @@ class PeriodicSecondaryRefreshTask(PeriodicTask):
     def __call__(self):
         pstart, pend = self._my_range()
         msg = _LI("Refreshing zones between for %(start)s to %(end)s")
-        LOG.info(msg % {"start": pstart, "end": pend})
+        LOG.info(msg, {"start": pstart, "end": pend})
 
         ctxt = context.DesignateContext.get_admin_context()
         ctxt.all_tenants = True
@@ -232,5 +234,67 @@ class PeriodicSecondaryRefreshTask(PeriodicTask):
             if seconds > zone.refresh:
                 msg = "Zone %(id)s has %(seconds)d seconds since last transfer, " \
                       "executing AXFR"
-                LOG.debug(msg % {"id": zone.id, "seconds": seconds})
-                self.central_api.xfr_domain(ctxt, zone.id)
+                LOG.debug(msg, {"id": zone.id, "seconds": seconds})
+                self.central_api.xfr_zone(ctxt, zone.id)
+
+
+class PeriodicGenerateDelayedNotifyTask(PeriodicTask):
+    """Generate delayed NOTIFY transactions
+    Scan the database for zones with the delayed_notify flag set.
+    """
+
+    __plugin_name__ = 'delayed_notify'
+    __interval__ = 5
+
+    def __init__(self):
+        super(PeriodicGenerateDelayedNotifyTask, self).__init__()
+
+    @classmethod
+    def get_cfg_opts(cls):
+        group = cfg.OptGroup(cls.get_canonical_name())
+        options = cls.get_base_opts() + [
+            cfg.IntOpt(
+                'interval',
+                default=cls.__interval__,
+                help='Run interval in seconds'
+            ),
+            cfg.IntOpt(
+                'batch_size',
+                default=100,
+                help='How many zones to receive NOTIFY on each run'
+            ),
+        ]
+        return [(group, options)]
+
+    def __call__(self):
+        """Fetch a list of zones with the delayed_notify flag set up to
+        "batch_size"
+        Call Pool Manager to emit NOTIFY transactions,
+        Reset the flag.
+        """
+        pstart, pend = self._my_range()
+
+        ctxt = context.DesignateContext.get_admin_context()
+        ctxt.all_tenants = True
+
+        # Select zones where "delayed_notify" is set and starting from the
+        # oldest "updated_at".
+        # There's an index on delayed_notify.
+        criterion = self._filter_between('shard')
+        criterion['delayed_notify'] = True
+        zones = self.central_api.find_zones(
+            ctxt,
+            criterion,
+            limit=self.options.batch_size,
+            sort_key='updated_at',
+            sort_dir='asc',
+        )
+
+        msg = _LI("Performing delayed NOTIFY for %(start)s to %(end)s: %(n)d")
+        LOG.debug(msg % dict(start=pstart, end=pend, n=len(zones)))
+
+        pm_api = PoolManagerAPI.get_instance()
+        for z in zones:
+            pm_api.update_zone(ctxt, z)
+            z.delayed_notify = False
+            self.central_api.update_zone(ctxt, z)
