@@ -57,6 +57,13 @@ function configure_designate {
     iniset $DESIGNATE_CONF DEFAULT root-helper sudo designate-rootwrap $DESIGNATE_ROOTWRAP_CONF
     iniset $DESIGNATE_CONF storage:sqlalchemy connection `database_connection_url designate`
 
+    # Quota Configuration
+    iniset $DESIGNATE_CONF DEFAULT quota_zones $DESIGNATE_QUOTA_ZONES
+    iniset $DESIGNATE_CONF DEFAULT quota_zone_recordsets $DESIGNATE_QUOTA_ZONE_RECORDSETS
+    iniset $DESIGNATE_CONF DEFAULT quota_zone_records $DESIGNATE_QUOTA_ZONE_RECORDS
+    iniset $DESIGNATE_CONF DEFAULT quota_recordset_records $DESIGNATE_QUOTA_RECORDSET_RECORDS
+    iniset $DESIGNATE_CONF DEFAULT quota_api_export_size $DESIGNATE_QUOTA_API_EXPORT_SIZE
+
     # Coordination Configuration
     if [[ -n "$DESIGNATE_COORDINATION_URL" ]]; then
         iniset $DESIGNATE_CONF coordination backend_url $DESIGNATE_COORDINATION_URL
@@ -84,9 +91,9 @@ function configure_designate {
     iniset $DESIGNATE_CONF service:api enabled_extensions_admin $DESIGNATE_ENABLED_EXTENSIONS_ADMIN
     iniset $DESIGNATE_CONF service:api api_host $DESIGNATE_SERVICE_HOST
     iniset $DESIGNATE_CONF service:api api_base_uri $DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT/
-    iniset $DESIGNATE_CONF service:api enable_api_v1 True
-    iniset $DESIGNATE_CONF service:api enable_api_v2 True
-    iniset $DESIGNATE_CONF service:api enable_api_admin True
+    iniset $DESIGNATE_CONF service:api enable_api_v1 $DESIGNATE_ENABLE_API_V1
+    iniset $DESIGNATE_CONF service:api enable_api_v2 $DESIGNATE_ENABLE_API_V2
+    iniset $DESIGNATE_CONF service:api enable_api_admin $DESIGNATE_ENABLE_API_ADMIN
 
     # mDNS Configuration
     iniset $DESIGNATE_CONF service:mdns host $DESIGNATE_SERVICE_HOST
@@ -149,6 +156,15 @@ function configure_designatedashboard {
 # Configure the needed tempest options
 function configure_designate_tempest() {
     if is_service_enabled tempest; then
+        # Tell tempest we're available
+        iniset $TEMPEST_CONFIG service_available designate True
+
+        # Tell tempest which APIs are available
+        iniset $TEMPEST_CONFIG dns_feature_enabled api_v1 $DESIGNATE_ENABLE_API_V1
+        iniset $TEMPEST_CONFIG dns_feature_enabled api_v2 $DESIGNATE_ENABLE_API_V2
+        iniset $TEMPEST_CONFIG dns_feature_enabled api_admin $DESIGNATE_ENABLE_API_ADMIN
+
+        # Tell tempest where are nameservers are.
         nameservers=$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT_DNS
         case $DESIGNATE_BACKEND_DRIVER in
             bind9|powerdns)
@@ -166,6 +182,9 @@ function configure_designate_tempest() {
             nameservers=$DESIGNATE_NAMESERVERS
         fi
 
+        iniset $TEMPEST_CONFIG dns nameservers $nameservers
+
+        # For legacy functionaltests
         iniset $TEMPEST_CONFIG designate nameservers $nameservers
     fi
 }
@@ -262,6 +281,12 @@ function install_designatedashboard {
     ln -fs $DESIGNATEDASHBOARD_DIR/designatedashboard/enabled/_1720_project_dns_panel.py $HORIZON_DIR/openstack_dashboard/local/enabled/_1720_project_dns_panel.py
 }
 
+# install_designatetempest - Collect source and prepare
+function install_designatetempest {
+    git_clone_by_name "designate-tempest-plugin"
+    setup_dev_lib "designate-tempest-plugin"
+}
+
 # start_designate - Start running processes, including screen
 function start_designate {
     start_designate_backend
@@ -313,6 +338,11 @@ if is_service_enabled designate; then
             install_designatedashboard
         fi
 
+        if is_service_enabled tempest; then
+            echo_summary "Installing Designate Tempest Plugin"
+            install_designatetempest
+        fi
+
     elif [[ "$1" == "stack" && "$2" == "post-config" ]]; then
         echo_summary "Configuring Designate"
         configure_designate
