@@ -24,16 +24,11 @@ from functionaltests.common import utils
 
 class ZoneClient(ClientMixin):
 
-    @classmethod
-    def zones_uri(cls, filters=None):
-        url = "/v2/zones"
-        if filters:
-            url = cls.add_filters(url, filters)
-        return url
+    def zones_uri(self, filters=None):
+        return self.create_uri("/zones", filters=filters)
 
-    @classmethod
-    def zone_uri(cls, id):
-        return "{0}/{1}".format(cls.zones_uri(), id)
+    def zone_uri(self, id):
+        return "{0}/{1}".format(self.zones_uri(), id)
 
     def list_zones(self, filters=None, **kwargs):
         resp, body = self.client.get(self.zones_uri(filters), **kwargs)
@@ -80,3 +75,8 @@ class ZoneClient(ClientMixin):
         except NotFound:
             return True
         return False
+
+    def zones_dot_json(self, filters=None, **kwargs):
+        uri = self.create_uri("/zones.json", filters=filters)
+        resp, body = self.client.get(uri, **kwargs)
+        return self.deserialize(resp, body, ZoneListModel)
