@@ -29,7 +29,7 @@ class BlacklistTest(DesignateV2Test):
     def test_list_blacklists(self):
         self.useFixture(BlacklistFixture())
         resp, model = BlacklistClient.as_user('admin').list_blacklists()
-        self.assertEqual(resp.status, 200)
+        self.assertEqual(200, resp.status)
         self.assertGreater(len(model.blacklists), 0)
 
     def test_create_blacklist(self):
@@ -43,19 +43,19 @@ class BlacklistTest(DesignateV2Test):
         patch_model = datagen.random_blacklist_data()
         resp, new_model = BlacklistClient.as_user('admin').patch_blacklist(
             old_model.id, patch_model)
-        self.assertEqual(resp.status, 200)
+        self.assertEqual(200, resp.status)
 
         resp, model = BlacklistClient.as_user('admin').get_blacklist(
             new_model.id)
-        self.assertEqual(resp.status, 200)
-        self.assertEqual(new_model.id, old_model.id)
-        self.assertEqual(new_model.pattern, model.pattern)
+        self.assertEqual(200, resp.status)
+        self.assertEqual(old_model.id, new_model.id)
+        self.assertEqual(model.pattern, new_model.pattern)
 
     def test_delete_blacklist(self):
         fixture = self.useFixture(BlacklistFixture())
         resp, model = BlacklistClient.as_user('admin').delete_blacklist(
             fixture.created_blacklist.id)
-        self.assertEqual(resp.status, 204)
+        self.assertEqual(204, resp.status)
 
     def test_get_blacklist_404(self):
         client = BlacklistClient.as_user('admin')
