@@ -15,6 +15,7 @@ limitations under the License.
 """
 
 import abc
+import logging
 
 from config import cfg
 from noauth import NoAuthAuthProvider
@@ -25,6 +26,9 @@ from tempest_lib.auth import KeystoneV2Credentials
 from tempest_lib.auth import KeystoneV2AuthProvider
 
 from functionaltests.common.utils import memoized
+from functionaltests.common import hooks
+
+LOG = logging.getLogger(__name__)
 
 
 class KeystoneV2AuthProviderWithOverridableUrl(KeystoneV2AuthProvider):
@@ -53,12 +57,49 @@ class KeystoneV2AuthProviderNoToken(KeystoneV2AuthProviderWithOverridableUrl):
 class BaseDesignateClient(RestClient):
 
     def __init__(self, with_token=True):
+        no_cert_check = cfg.CONF.testconfig.disable_ssl_certificate_validation
+
+        interface = cfg.CONF.designate.interface
+        if not interface.endswith('URL'):
+            interface += "URL"
+
+        self.hooks = []
+        self._populate_hooks()
+
         super(BaseDesignateClient, self).__init__(
             auth_provider=self.get_auth_provider(with_token),
-            service='dns',
-            region=cfg.CONF.identity.region
+            service=cfg.CONF.designate.service,
+            region=cfg.CONF.identity.region,
+            disable_ssl_certificate_validation=no_cert_check,
+            endpoint_type=interface
         )
 
+    def _populate_hooks(self):
+        for name in cfg.CONF.testconfig.hooks:
+            LOG.debug("Loading request hook '%s' from config", name)
+            try:
+                cls = hooks.get_class(name)
+                if not cls:
+                    LOG.debug("'%s' not found. Call register_hook", name)
+                else:
+                    self.hooks.append(cls)
+            except Exception as e:
+                LOG.exception(e)
+
+    def request(self, *args, **kwargs):
+        req_hooks = [hook_class() for hook_class in self.hooks]
+        try:
+            for hook in req_hooks:
+                hook.before(args, kwargs)
+            r, b = super(BaseDesignateClient, self).request(*args, **kwargs)
+            for hook in req_hooks:
+                hook.after(r, b)
+            return r, b
+        except Exception as e:
+            for hook in req_hooks:
+                hook.on_exception(e)
+            raise
+
     def get_auth_provider(self, with_token=True):
         if cfg.CONF.noauth.use_noauth:
             return self._get_noauth_auth_provider()
@@ -130,9 +171,9 @@ class DesignateAdminClient(BaseDesignateClient):
 
     def _get_keystone_auth_provider(self, with_token=True):
         creds = KeystoneV2Credentials(
-            username=cfg.CONF.identity.admin_username,
-            password=cfg.CONF.identity.admin_password,
-            tenant_name=cfg.CONF.identity.admin_tenant_name,
+            username=cfg.CONF.auth.admin_username,
+            password=cfg.CONF.auth.admin_password,
+            tenant_name=cfg.CONF.auth.admin_tenant_name,
         )
         return self._create_keystone_auth_provider(creds, with_token)
 
@@ -184,3 +225,18 @@ class ClientMixin(object):
             )
             first = False
         return url
+
+    def create_uri(self, path, filters=None):
+        url_pattern = cfg.CONF.testconfig.v2_path_pattern
+        params = {
+            'path': path,
+            'tenant_id': self.client.tenant_id,
+            'tenant_name': self.client.tenant_name,
+            'user': self.client.user,
+            'user_id': self.client.user_id,
+        }
+        uri = url_pattern.format(**params)
+        uri.replace('//', '/')
+        if filters:
+            uri = self.add_filters(uri, filters)
+        return uri
